{"": "", "Apply changes": "Menerapkan perubahan", "Cancel": "Membatalkan", "Close": "Tutup", "Mark for installation": "Tandai untuk instalasi", "Mark for removal": "Tandai untuk dihapus", "Mark for upgrade": "Tandai untuk upgrade", "Search packages": "Cari paket", "Selections": "Pilihan", "Update package list": "Perbarui daftar paket", "Upgradeable": "Bisa diupgrade", "pending": "tertunda", "Packages": "Paket", "Install/remove packages": "Instal/hapus paket", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}