{"": "", "Apply changes": "Aplica\u021bi modific\u0103rile", "Cancel": "Anulare", "Close": "\u00cenchidere", "Mark for installation": "Marcare pentru instalare", "Mark for removal": "Marcare pentru \u0219tergere", "Mark for upgrade": "Marcare pentru actualizare", "Search packages": "C\u0103utare pachete", "Selections": "Selec\u021bii", "Update package list": "Actualiza\u021bi lista de pachete", "Upgradeable": "Actualizabile", "pending": "\u00een a\u0219teptare", "Packages": "Pachete", "Install/remove packages": "Instalare/eliminare pachete", "Could not find packages": "Nu s-au putut g\u0103si pachete", "Package list update started": "Actualizarea listei de pachete a \u00eenceput", "Package list update failed": "Actualizarea listei de pachete a e\u0219uat", "Could not apply changes": "Modific\u0103rile nu au putut fi aplicate"}