{"": "", "Apply changes": "Aplicar cambios", "Cancel": "Cancelar", "Close": "Cerrar", "Mark for installation": "Marcar para instalaci\u00f3n", "Mark for removal": "Marcar para eliminaci\u00f3n", "Mark for upgrade": "Marca para actualizaci\u00f3n", "Search packages": "Buscar paquetes", "Selections": "Selecciones", "Update package list": "Actualizar lista de paquetes", "Upgradeable": "Actualizable", "pending": "pendiente", "Packages": "Paquetes", "Install/remove packages": "Instalar/quitar paquetes", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}