{"": "", "Apply changes": "Zastosuj zmiany", "Cancel": "Anuluj", "Close": "", "Mark for installation": "", "Mark for removal": "Zaznacz do usuni\u0119cia", "Mark for upgrade": "Zaznacz do uaktualnienia", "Search packages": "", "Selections": "", "Update package list": "Aktualizacja listy pakiet\u00f3w", "Upgradeable": "Mo\u017cliwe do zaktualizowania", "pending": "", "Packages": "Paczki", "Install/remove packages": "", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}