{"": "", "Apply changes": "\u00c4nderungen \u00fcbernehmen", "Cancel": "Abbrechen", "Close": "Schlie\u00dfen", "Mark for installation": "F\u00fcr Installation markieren", "Mark for removal": "Zum L\u00f6schen markieren", "Mark for upgrade": "F\u00fcr Update markieren", "Search packages": "Packete Suchen", "Selections": "Auswahl", "Update package list": "Package List aktualisieren", "Upgradeable": "Aktualisierbar", "pending": "warten", "Packages": "Packete", "Install/remove packages": "Installieren/Entfernen von Paketen", "Could not find packages": "Pakete konnten nicht gefunden werden", "Package list update started": "Paket-Listen-Update gestartet", "Package list update failed": "Paket-Listen-Update fehlgeschlagen", "Could not apply changes": "Die \u00c4nderungen konnten nicht \u00fcbernommen werden"}