{"": "", "Apply changes": "Aplicar as altera\u00e7\u00f5es", "Cancel": "Cancelar", "Close": "Fechar", "Mark for installation": "Marcar para instala\u00e7\u00e3o", "Mark for removal": "Marca para remo\u00e7\u00e3o", "Mark for upgrade": "Marcar para atualiza\u00e7\u00e3o", "Search packages": "Pesquisar pacotes", "Selections": "Sele\u00e7\u00f5es", "Update package list": "Lista de pacotes de atualiza\u00e7\u00e3o", "Upgradeable": "Atualiz\u00e1vel", "pending": "pendente", "Packages": "Pacotes", "Install/remove packages": "Instalar/remover pacotes", "Could not find packages": "N\u00e3o foi poss\u00edvel encontrar pacotes", "Package list update started": "Atualiza\u00e7\u00e3o da lista de pacotes iniciada", "Package list update failed": "Atualiza\u00e7\u00e3o da lista de pacotes falhou", "Could not apply changes": "N\u00e3o foi poss\u00edvel aplicar as altera\u00e7\u00f5es"}