{"": "", "Apply changes": "\ubcc0\uacbd\uc0ac\ud56d \uc801\uc6a9", "Cancel": "\ucde8\uc18c", "Close": "\ub2eb\uae30", "Mark for installation": "\uc124\uce58\ud560 \ud56d\ubaa9", "Mark for removal": "\uc0ad\uc81c\ud560 \ud56d\ubaa9", "Mark for upgrade": "\uc5c5\uadf8\ub808\uc774\ub4dc\ud560 \ud56d\ubaa9", "Search packages": "\ud328\ud0a4\uc9c0 \uac80\uc0c9", "Selections": "\uc120\ud0dd", "Update package list": "\ud328\ud0a4\uc9c0 \ubaa9\ub85d \uc5c5\ub370\uc774\ud2b8", "Upgradeable": "\uc5c5\uadf8\ub808\uc774\ub4dc \uac00\ub2a5", "pending": "", "Packages": "\ud328\ud0a4\uc9c0", "Install/remove packages": "\ud328\ud0a4\uc9c0 \uc124\uce58/\uc0ad\uc81c", "Could not find packages": "\ud328\ud0a4\uc9c0\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4", "Package list update started": "\ud328\ud0a4\uc9c0 \ubaa9\ub85d \uc5c5\ub370\uc774\ud2b8 \uc2dc\uc791", "Package list update failed": "\ud328\ud0a4\uc9c0 \ubaa9\ub85d \uc5c5\ub370\uc774\ud2b8 \uc2e4\ud328", "Could not apply changes": "\ubcc0\uacbd\uc0ac\ud56d\uc744 \uc801\uc6a9\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4"}