{"": "", "Apply changes": "Uveljavi spremembe", "Cancel": "Prekli\u010di", "Close": "Zapri", "Mark for installation": "Ozna\u010di za namestitev", "Mark for removal": "Ozna\u010di za odstranitev", "Mark for upgrade": "Ozna\u010di za nadgradnjo", "Search packages": "Iskanje paketov", "Selections": "Izbira", "Update package list": "Posodobi seznam paketov", "Upgradeable": "Nadgradljivo", "pending": "na \u010dakanju", "Packages": "Paketi", "Install/remove packages": "Namestite/odstranite pakete", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}