{"": "", "Apply changes": "De\u011fi\u015fiklikleri uygula", "Cancel": "\u0130ptal", "Close": "Kapat", "Mark for installation": "Y\u00fckleme i\u00e7in i\u015faretle", "Mark for removal": "Kald\u0131rma i\u00e7in i\u015faretle", "Mark for upgrade": "Y\u00fckseltme i\u00e7in i\u015faretle", "Search packages": "Paket ara", "Selections": "Se\u00e7imler", "Update package list": "G\u00fcncelle\u015ftirme paketi listesi", "Upgradeable": "Y\u00fckseltilebilir", "pending": "beklemede", "Packages": "Paketler", "Install/remove packages": "Paket Y\u00fckle/Kald\u0131r", "Could not find packages": "Paketler bulunamad\u0131", "Package list update started": "Paket listesi g\u00fcncellemesi ba\u015flad\u0131", "Package list update failed": "Paket listesi g\u00fcncellemesi ba\u015far\u0131s\u0131z", "Could not apply changes": "De\u011fi\u015fiklikler uygulanamad\u0131"}