{"": "", "Apply changes": "\u5e94\u7528\u53d8\u66f4", "Cancel": "\u53d6\u6d88", "Close": "\u5173\u95ed", "Mark for installation": "\u6807\u8bb0\u4ee5\u4fbf\u5b89\u88c5", "Mark for removal": "\u6807\u8bb0\u4ee5\u4fbf\u5220\u9664", "Mark for upgrade": "\u6807\u8bb0\u4ee5\u4fbf\u5347\u7ea7", "Search packages": "\u641c\u7d22\u8f6f\u4ef6\u5305", "Selections": "\u9009\u62e9", "Update package list": "\u66f4\u65b0\u8f6f\u4ef6\u5305\u5217\u8868", "Upgradeable": "\u53ef\u5347\u7ea7", "pending": "\u6302\u8d77", "Packages": "\u8f6f\u4ef6\u5305", "Install/remove packages": "\u5b89\u88c5\u6216\u5220\u9664\u8f6f\u4ef6", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}