{"": "", "Apply changes": "Pas wijzigingen toe", "Cancel": "Annuleren", "Close": "Sluiten", "Mark for installation": "", "Mark for removal": "Aanmerken voor verwijdering", "Mark for upgrade": "Markeren voor upgrade", "Search packages": "", "Selections": "Selecties", "Update package list": "", "Upgradeable": "", "pending": "in behandeling", "Packages": "", "Install/remove packages": "", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}