{"": "", "Apply changes": "Wizigingen tapasse", "Cancel": "Annulearje", "Close": "Slute", "Mark for installation": "", "Mark for removal": "", "Mark for upgrade": "", "Search packages": "", "Selections": "", "Update package list": "", "Upgradeable": "", "pending": "", "Packages": "", "Install/remove packages": "", "Could not find packages": "", "Package list update started": "", "Package list update failed": "", "Could not apply changes": ""}