{"": "", "Apply changes": "Till\u00e4mpa \u00e4ndringar", "Cancel": "Avbryt", "Close": "St\u00e4ng", "Mark for installation": "Markera f\u00f6r installation", "Mark for removal": "Markera f\u00f6r borttagning", "Mark for upgrade": "Markera f\u00f6r uppgradering", "Search packages": "S\u00f6k paket", "Selections": "Markeringar", "Update package list": "Uppdatera paketlistan", "Upgradeable": "Uppgraderingsbar", "pending": "v\u00e4ntar", "Packages": "Paket", "Install/remove packages": "Installera/ta bort paket", "Could not find packages": "Kunde inte hitta paket", "Package list update started": "Paketlistans uppdatering startad", "Package list update failed": "Paketlistan uppdateringen misslyckades", "Could not apply changes": "Kunde inte till\u00e4mpa \u00e4ndringar"}