{"": "", "Apply changes": "Applica le modifiche", "Cancel": "Annulla", "Close": "Chiudi", "Mark for installation": "Seleziona per installazione", "Mark for removal": "Seleziona per rimozione", "Mark for upgrade": "Seleziona per aggiornamento", "Search packages": "Cerca pacchetto", "Selections": "Selezioni", "Update package list": "Aggiorna la lista dei pacchetti", "Upgradeable": "Aggiornabile", "pending": "in attesa", "Packages": "Pacchetti", "Install/remove packages": "Installa/Rimuovi pacchetti", "Could not find packages": "Impossibile trovare i pacchetti", "Package list update started": "Aggiornamento elenco pacchetti avviato", "Package list update failed": "Aggiornamento elenco pacchetti fallito", "Could not apply changes": "Impossibile applicare le modifiche"}