{"": "", "Apply changes": "Appliquer les modifications", "Cancel": "Annuler", "Close": "Fermer", "Mark for installation": "Marquer pour installation", "Mark for removal": "Marquer pour suppression", "Mark for upgrade": "Marquer pour mise \u00e0 jour", "Search packages": "Chercher un paquet", "Selections": "S\u00e9lections", "Update package list": "Mettre \u00e0 jour la liste des paquets", "Upgradeable": "Nouvelle version disponible", "pending": "en attente", "Packages": "Paquets", "Install/remove packages": "Installer/supprimer des paquets", "Could not find packages": "Impossible de trouver les paquets", "Package list update started": "La mise \u00e0 jour de la liste des paquets a commenc\u00e9", "Package list update failed": "La mise \u00e0 jour de la liste des paquets a \u00e9chou\u00e9", "Could not apply changes": "Impossible d'appliquer les modifications"}